//---------------------------------------------------------------------------


#pragma hdrstop

#include "Recorder.h"

#include <json/json.h>
#include <fstream>
#include <time.h>
#include <stdio.h>

//---------------------------------------------------------------------------

#pragma package(smart_init)


int Recorder::Store(const std::string &filename, const enum E_FMT format,
		const std::vector<float> &data,
		const struct timeb &timestamp, float fDivX, int coupling, int trigger_type)
{
	int status;
	if (format == FMT_JSON)
		status = StoreJson(filename, data, timestamp, fDivX, coupling, trigger_type);
	else if (format == FMT_CSV)
		status = StoreCsv(filename, data, fDivX);
	else
		return -1;
	return status;
}


int Recorder::StoreJson(const std::string &filename, const std::vector<float> &data,
	const struct timeb &timestamp, float fDivX, int coupling, int trigger_type)
{
	Json::Value root;
	Json::StyledWriter writer;

	char* timeline = ctime( & ( timestamp.time ) );
	timeline[19]=0;
	char buf[64];
	sprintf(buf, "%15s.%03hu", &timeline[4], timestamp.millitm);

	root["Timestamp"] = buf;
	root["fDivX"] = fDivX;
	root["Coupling"] = coupling;
	root["TriggerType"] = trigger_type;

	for (unsigned int i=0; i<data.size(); i++)
	{
		// see json_writer for default precision
		root["Data"][i] = data[i];
	}

	std::string outputConfig = writer.write( root );
	std::ofstream ofs(filename.c_str());
	if (!ofs.is_open())
		return -2;

	ofs << outputConfig;
	ofs.close();
	return 0;
}

int Recorder::StoreCsv(const std::string &filename, const std::vector<float> &data,
	float fDivX)
{
	std::ofstream ofs(filename.c_str());
	if (!ofs.is_open())
		return -2;

	ofs << "Time,Voltage";
	float time = 0;
	for (unsigned int i=0; i<data.size(); ++i)
	{
		ofs << "\r\n" << time << "," << data[i];
		time += fDivX;
	}
	ofs.close();
	return 0;
}


